### CODE LOG: Patterns of Style, Diversity, and Similarity in Middle Orinoco rock art assemblages ###

## Philip Riris and Jose Oliver (UCL Institute of Archaeology)

## Load packages and data

require(tidyverse)
require(igraph)
require(statnet)
require(ggraph)
require(tidygraph)
require(vegan)
require(egg)
require(reshape2)

rat <- read.csv("rockart_attr_middleorinoco.csv", header=TRUE)
rcn <- read.csv("rockart_count_middleorinoco.csv", header=TRUE)

## FIGURE 3

# Summary statistics

row.names(rcn) <- rcn$Site
rcn[2:3] <- NULL # Remove UniqID and Unclassified columns

rcn2 <- rowSums(rcn[2:71]) # Sum motif counts by site

rcn2 <- as.data.frame(rcn2)
rcn2$Site <- rcn$Site

names(rcn2)[1] <- "Count"

summary <- ggplot(rcn2, aes(x=reorder(Site, -Count), y=Count)) + 
  geom_bar(stat="identity", aes(fill=rat$ArtType), color="grey40", size=0.1) + 
  theme_bw() +
  theme(axis.text.x=element_text(angle = 45, vjust = 1, hjust=1, size=6)) +
  xlab("Site") +
  scale_fill_brewer(palette="Set2", name="") + guides(fill=FALSE)

# Calculate diversity index

rcn2$Div <- diversity(rcn[-1], index="shannon") # Diversity H
rcn2$Div2 <- exp(rcn2$Div) # True diversity H'

#NOT RUN
#pic <- subset(rcn2, rat$ArtType=="Painted")
#pet <- subset(rcn2, rat$ArtType=="Engraved")
#allfit <- lm(log(rcn2$Count) ~ rcn2$Div2) #Adjusted R-squared:  0.882 
#picfit <- lm(log(pic$Count) ~ pic$Div2) #Adjusted R-squared:  0.9021 
#petfit <- lm(log(pet$Count) ~ pet$Div2) #Adjusted R-squared:  0.776 

diversity <- ggplot(data = rcn2, aes(x=Count, y = Div)) +
  ylab("Shannon entropy") + theme_bw() +
  geom_smooth(color = "#909DCA", se = FALSE, method = "gam", formula = y ~ s(log(x))) +
  geom_point(aes(colour=rat$ArtType), size=2) + scale_color_brewer(palette="Set2", name="Type") +
  annotate("text", x = 200, y = 2, label = "italic(R) ^ 2 == 0.882",
           parse = TRUE)

ggarrange(plots = list(summary, diversity), ncol = 2)

## FIGURE 4

# Co-presence function from:
# Peeples, Matthew A.
# 2017 Network Science and Statistical Techniques for Dealing with Uncertainties in
# Archaeological Datasets. [online]. Available: http://www.mattpeeples.net/netstats.html

# Co-presence function
co.p <- function(x, thresh) { 
  temp <- prop.table(as.matrix(x), 1) 
  temp[temp >= thresh] <- 1 
  temp[temp < 1] <- 0 
  out <- temp %*% t(temp) 
  diag(out) <- 0
  return(out) 
} 

rcn3 <- rcn[-1] # Subset out site names column

rco.p <- co.p(rcn3, thresh=0.05)

# weighted Jaccard similarity
sim.jac <- matrix(0, nrow=nrow(rcn3), ncol=nrow(rcn3))
rownames(sim.jac) <- rownames(rcn3)
colnames(sim.jac) <- rownames(rcn3)
pairs <- t(combn(1:nrow(rcn3), 2))

for (i in 1:nrow(pairs)){
  num <- sum(sapply(1:ncol(rcn3), function(x)(min(rcn3[pairs[i,1],x],rcn3[pairs[i,2],x]))))
  den <- sum(sapply(1:ncol(rcn3), function(x)(max(rcn3[pairs[i,1],x],rcn3[pairs[i,2],x]))))
  sim.jac[pairs[i,1],pairs[i,2]] <- num/den
  sim.jac[pairs[i,2],pairs[i,1]] <- num/den  
}

sim.jac[which(is.na(sim.jac))] <- 0
diag(sim.jac) <- 0

# Correlation matrices

# Co-presence

# Lower triangle extraction function
get_lower_tri<-function(rco.p){
  rco.p[lower.tri(rco.p)] <- NA
  return(rco.p)
}

cop.lo <- get_lower_tri(rco.p)
diag(cop.lo) <- NA


cop.lo <- melt(cop.lo, na.rm = TRUE)

cop.plot <- ggplot(data = cop.lo, aes(Var2, Var1, fill = value))+
  geom_tile(color = "white")+
  scale_fill_viridis_c(limit = c(1,4), option="B", name="Co-presence", na.value="white") + 
  coord_fixed() +
  theme(axis.text.x = element_text(angle = 45, vjust = 1, 
                                   size = 6, hjust = 1),
        axis.text.y = element_text(size=6),
        axis.title.x = element_blank(),
        axis.title.y = element_blank(),
        legend.justification = c(1, 0),
        legend.position = c(0.5, 0.6),
        legend.direction = "horizontal",
        panel.grid.major = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank(),
        legend.text = element_text(angle = 45, size=10)) +
  guides(fill = guide_colorbar(barwidth = 3.5, barheight = 0.5,
                               title.position = "top", title.hjust = 0.5))

# Jaccard

# Lower triangle extraction function
get_lower_tri<-function(sim.jac){
  sim.jac[lower.tri(sim.jac)] <- NA
  return(sim.jac)
}

jac.lo <- get_lower_tri(sim.jac)
diag(jac.lo) <- NA

jac.lo <- melt(jac.lo, na.rm = TRUE)

jac.plot <- ggplot(data = jac.lo, aes(Var2, Var1, fill = value)) +
  geom_tile(color = "white") +
  scale_fill_viridis_c(limit = c(0.00001,0.33), option="B", name="Jaccard\nsimilarity", na.value="white") +
  theme(axis.text.x = element_text(angle = 45, vjust = 1, 
                                   size = 6, hjust = 1),
        axis.text.y = element_text(size=6),
        axis.title.x = element_blank(),
        axis.title.y = element_blank(),
        legend.justification = c(1, 0),
        legend.position = c(0.5, 0.6),
        legend.direction = "horizontal",
        panel.grid.major = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank(),
        legend.text = element_text(angle = 45, size=10, hjust=1)) +
  coord_fixed() +
  guides(fill = guide_colorbar(barwidth = 3.5, 
                               barheight = 0.5,
                               title.position = "top", 
                               title.hjust = 0.5))

ggarrange(plots = list(cop.plot, jac.plot), ncol = 2)

# Networks

jnet<- network(event2dichot(sim.jac, method = "absolute", thresh = 0.1),  
                 directed = F, names.eval = "weight")


jnet <- as_tbl_graph(jnet, directed = FALSE) %>% # convert network to tibble graph
  mutate(deg = centrality_degree())

style.graph <- ggraph(jnet) + geom_edge_link(alpha=0.4, edge_width=0.75, show.legend = FALSE) + 
  geom_node_point(aes(color=deg, shape=rat$ArtType, size=4)) + 
  scale_color_viridis_c(name = "Degree", direction=-1, option="C") + 
  scale_shape_discrete(name="Type") +
  theme_graph() + geom_node_text(aes(label=name), size=2.5, repel=TRUE) +
  guides(size="none")

t <- as_tibble(jnet)
rcn2 <- cbind(t, rcn2)

small <- subset(rcn2, rcn2$Div2 < 20) # Subset out largest two sites

deg.div <- ggplot(rcn2, aes(deg, Div2)) + 
  geom_point() + xlab("Degree") + ylab("Diversity (H')") +
  geom_smooth(method="lm", se=FALSE, color="red") + theme_bw() +
  annotate("text", x = 11, y = 24, label = "italic(R) ^ 2 == 0.0059",
           parse = TRUE, col="red") +
  annotate("text", x = 10.8, y = 22, label = "italic(p) == 0.28",
           parse = TRUE, col="red") +
  geom_smooth(data=small, aes(x=deg, y=Div2), method="lm", se=FALSE, color="darkred", linetype="dashed") + theme_bw() +
  annotate("text", x = 11, y = 19, label = "italic(R) ^ 2 == 0.3204",
           parse = TRUE, col="darkred") +
  annotate("text", x = 10.8, y = 17, label = "italic(p) < 0.0001",
           parse = TRUE, col="darkred")

ggarrange(plots=list(style.graph, deg.div), ncol=2)

